//
// FOR FIGURE 1 
// ENDOGENOUS CAPITAL & MONETARY POLICY RESPONSE TO SHARE PRICE
//

set(0,'defaultAxesFontSize',12);
set(0,'defaultAxesFontName','century');
set(0,'defaultTextFontSize',12);
set(0,'defaultTextFontName','century');

var c r pi qk z rk w h k i yy q d;
varexo e ;

parameters sigma gamma phi z_ss beta lambda tau_pi tau_y tau_q tau_qk delta alpha delta eta k_ss y_ss c_ss cy_ss; 

sigma=2;
gamma=2;

z_ss = .85;
beta = .99;

delta = .025;
eta=.5;

lambda = 0.019;

%tau_pi =1.1;
tau_y = 0;
tau_q=0;
%tau_qk=0;

alpha=.3

k_ss=(alpha*z_ss/(1/beta-1+delta))^(1/(1-alpha));
y_ss=k_ss^alpha;
c_ss=y_ss-delta*eta*k_ss;
cy_ss=c_ss/y_ss;


% main loop

min_tau_pi = 0.5;
max_tau_pi = 3;
min_tau_q  = 0;
max_tau_q  = .5;

tau_pi_candidate = [min_tau_pi:(max_tau_pi-min_tau_pi)/40:max_tau_pi] ;
tau_q_candidate = [min_tau_q:(max_tau_q-min_tau_q)/40:max_tau_q] ;


grid1 = length(tau_pi_candidate);
grid2 = length(tau_q_candidate);


BFflag = NaN(grid1,grid2);

figure (1) ;
plot(0,0); hold on;

//tic;

for loop1 = 1:grid1;
        tau_pi=tau_pi_candidate(loop1);

for loop2 = 1:grid2;
        tau_q=tau_q_candidate(loop2);



disp('-----------------------------------------');
loop_num = [loop1,loop2]
disp('-----------------------------------------');



model;
    sigma*c+gamma*h=w;
    sigma*(c(+1)-c) = r-pi(+1);
    q=beta*q(+1)  +(1-beta)*d(+1)+pi(+1)-r;
    qk=beta*(1-delta)*qk(+1) +(1-beta*(1-delta))*rk(+1)+pi(+1)-r;
    w=z+yy-h;
   rk=z+yy-k(-1);
   d=yy-z_ss/(1-z_ss)*z;

    qk=(1-eta)*i;
    yy=alpha*k(-1)+(1-alpha)*h;
    cy_ss*c+(1-cy_ss)*i=yy;
    k=(1-delta)*k(-1)+delta*i;

   pi =beta*pi(+1)+lambda*z;
   r=tau_pi*pi + tau_y*yy + tau_q*q;//
  
end;

initval;
    c=0;
    w=0;
    r=0; 
    pi=0; 
    q=0; 
    d=0; 
    z=0;
    h=0;
    yy=0;
    k=0;
    i=0;

    rk=0;
    qk=0;

    e=0;
end;

//steady ;

check;

if sum(abs(eigenvalues_)>1.00001)==6 ;
    BFflag(loop1,loop2) = 50 ; % determinacy
    figure(1);
    plot(tau_q,tau_pi,'dr'); 
elseif sum(abs(eigenvalues_)>1.00001)<6 ;
    BFflag(loop1,loop2) = 0 ; % indeterminacy
    figure(1);
%    plot(tau_q,tau_pi,'xb'); 
elseif sum(abs(eigenvalues_)>1.00001)>6 ;   
    BFflag(loop1,loop2) = 255 ; % non stationary    
    figure(1);
%    plot(tau_q,tau_pi,'*k'); 
end ;




%---------------------------------------------------------------------------

end ;
end;

//toc;

figure(1);
%title('o : determinate,   x : indeterminate   * no eq.');
ylabel('tau pi');
xlabel('tau q');
 axis([ min_tau_q, max_tau_q,min_tau_pi,max_tau_pi ]); 
hold off;


